function P = PH_Aasym2(q,d)
% function P = PH_Aasym2(q,d)
%
%  d: scalar value. observed KS-distance for two samples of different sizes
% q=[q1 q2]: number of bars. We are dealing with the different
% number of bars
%
%
% The function computes the asympotic probability in Theorem 3 in 
% Chung, M.K., Ombao, H. 2021 Lattice paths for persistent diagrams. 
% Lecture Notes in Computer Science 12929:77-86  
% http://www.stat.wisc.edu/~mchung/papers/chung.2021.MICCAI.pdf
%
%
% The result genearlizes Theorem 3 (q1 = q2) in
% Chung, M.K., Vilalta-Gil, V., Lee, H., Rathouz, P.J., Lahey, B.B., Zald, D.H. 
% 2017 Exact Topological Inference for Paired Brain Networks via Persistent Homology,
% Information Processing in Medical Imaging (IPMI)
% http://www.stat.wisc.edu/~mchung/papers/chung.2017.IPMI.pdf
%
%
% If you are using this code, please reference tha above paper. 
%
% (C) 2017- Moo K. Chung                         
%     University of Wisconsin-Madison
%     mkchung@wisc.edu
%
% 2017 Dec. 18 created
% 2018 Jun. 04 edited
% 2021 Mar  28. Modified from PH_Aasym.m
% 2021 Sept 25. Comment added

q1=q(1);
q2=q(2);

if d>0
    d0= d*sqrt((q1*q2)/(q1+q2));
    P = 0;
    for i=1:100
        P = P + 2*(-1)^(i-1)*exp(-2*i^2*d0.^2);
    end
else% when d=0, p-value = 1
    P=1;
end
