function [height hprime] = PH_latticepath3(birth, death)
%function [height hprime] = PH_latticepath3(birth, death)
%
%The function transforms a persistent diagram into lattice path representation
%
% height: the height at the birth values
% hprime: h' in the paper 
%
% The function is explained in detail in  
% Chung, M.K., Ombao, H. 2021 Lattice paths for persistent diagrams. 
% Lecture Notes in Computer Science 12929:77-86  
% http://www.stat.wisc.edu/~mchung/papers/chung.2021.MICCAI.pdf
%
% (C) 2021 Moo K. Chung, mkchung@wisc.edu
%  Department of Biostatisics and Medical Informatics
%  University of Wisconsin, Madison
%
% This is Version 3.

n = length(birth);
arrows =[zeros(n,1); ones(n,1)];  %0 birth  (right arrow) +1 death (up arrow)
combined=[birth;death];
[c ind]  = sort(combined);
arrows = arrows(ind); %birth-death process

h = cumsum(arrows); %height of boxes as we traverse the lattice path
%figure; plot(h)
height = h(~logical(arrows)); %height at the birth values


%make heights unique
hunique = unique(height); % which will give you the unique elements of A in array B
Nrepeat = histc(height, hunique);

alpha=[];
for i=1:length(hunique)
     alpha = [alpha [0:Nrepeat(i)-1]/Nrepeat(i)];    
end

hprime = height+alpha';
%hold on; plot(hprime,'g')