function [F1, F2, x, d]= PH_mono2(W1, W2)
%function [F1, F2, x, d]= PH_mono2(W1, W2)
%
%The function transforms monotone lattice paths W1 and W2
%into normalized step functions and 
%
% height: the height at the birth values
% hprime: h' in the paper 
%

% W1, W2 :  Monotone features to compare
% F1, F2 :  monontone function values
% x      :  x-coordinates where F1 and F2 are sampled
% d      :  maximum gap
%
% The concept follows the method originally given in
% Chung, M.K., Vilalta-Gil, V., Lee, H., Rathouz, P.J., Lahey, B.B., Zald, D.H. 
% 2017 Exact Topological Inference for Paired Brain Networks via Persistent Homology,
% Information Processing in Medical Imaging (IPMI)
% http://www.stat.wisc.edu/~mchung/papers/chung.2017.IPMI.pdf
%
% It is further explained in 
% Chung, M.K., Ombao, H. 2021 Lattice paths for persistent diagrams. 
% Lecture Notes in Computer Science 12929:77-86  
% http://www.stat.wisc.edu/~mchung/papers/chung.2021.MICCAI.pdf
%
%
% (C) 2018 Moo K. Chung, mkchung@wisc.edu
%  Department of Biostatisics and Medical Informatics
%  University of Wisconsin, Madison
%
% 2021 March 27, modified from PH_monotone.m 

%W1=h6VXX_B;
%W2=h6VYB_B;

x           =  sort([W1;W2]); %combine x arguments
            
binCounts1  =  histc (W1 , x, 1); %emprical distribution
binCounts2  =  histc (W2 , x, 1); %emprical distribution

F1  =  cumsum(binCounts1); %./sum(binCounts1);
F2  =  cumsum(binCounts2); %./sum(binCounts2);

F1 = F1/F1(end);
F2 = F2/F2(end);
x = x/x(end);

%figure; plot(x,F1,'k')
%hold on; plot(x,F2,'r')

[d ind]= max(abs(F1-F2));
%x_max = x(ind); 


