% (C) 2021 Moo K. Chung
%
%     University of Wisconsin-Madison
%     http://www.stat.wisc.edu/~mchung
%     mkchung@wisc.edu
%
%  Sept 25, 2021

%% 6VXX CLOSED STATE
% Structure of the SARS-CoV-2 spike glycoprotein (closed state) published
% in the paper by Walls, A.C., Park, Y.J., Tortorici, M.A., Wall, A., 
% Seattle Structural Genomics Center for Infectious Disease (SSGCID)

%The coordinates of 7604 atoms for A, B and C domains. 
A_closed = load('6VXX-A.txt');
B_closed = load('6VXX-B.txt');
C_closed = load('6VXX-C.txt');
    
%% 6VYB OPEN STATE
% Structure of the SARS-CoV-2 spike glycoprotein (open state) published
% in the paper by Walls, A.C., Park, Y.J., Tortorici, M.A., Wall, A., 
% Seattle Structural Genomics Center for Infectious Disease (SSGCID)

A_open = load('6VYB-A.txt');  %7393 atoms
B_open = load('6VYB-B.txt');  %6865 atoms
C_open = load('6VYB-C.txt');  %7281 atoms

%% 6JX7 FELINE
%Published in the paper 
%Cryo-EM analysis of a feline coronavirus spike protein 
%reveals a unique structure and camouflaging glycans.
%Yang, T.J., Chang, Y.C., Ko, T.P., Draczkowski, P., 
%Chien, Y.C., Chang, Y.C., Wu, K.P., Khoo, K.H., Chang, H.W., Hsu, S.D.
%PNAS 2020) Proc Natl Acad Sci U S A 117: 1438-1446

%9768 atoms
A_feline = load('6JX7-A.txt');  
B_feline = load('6JX7-B.txt');  
C_feline = load('6JX7-C.txt');  

%% COMPUTING Inter-atomic distances

pairwise_B_closed = pdist(B_closed);
distances_B_closed= squareform(pairwise_B_closed);
figure; imagesc(distances_B_closed); axis square; colorbar
title('Inter-atomic distances: domain B (closed) of 6VYB');

pairwise_B_open = pdist(B_open);
distances_B_open= squareform(pairwise_B_open);
figure; imagesc(distances_B_open); axis square; colorbar
title('Inter-atomic distances: domain B (open) of 6VYB');


%Inter-atomic distance matrices are feed into Ripsur package 
%https://arxiv.org/pdf/1908.02518.pdf 
%We used the R-package version.
%and the persistent diagram coordinates are computed. Here we will assume
%you have the scatter points coordinates for persistent diagrams.

%% Displaying persistent diagram

[x0_open y0_open] = PH_read_ripsur('vr_d6VYB_B.txt', 0);
[x1_open y1_open] = PH_read_ripsur('vr_d6VYB_B.txt', 1);

figure; 
plot(x0_open,y0_open,'.r')
hold on; 
plot(x1_open,y1_open,'.k')
xlim([0 18])
ylim([0 18])
axis square;
xlabel('birth'); ylabel('death')
xticks([0:4:20])
yticks([0:4:20])
legend('0D homology','1D homology')

[x0_closed y0_closed] = PH_read_ripsur('vr_d6VXX_B.txt', 0);
[x1_closed y1_closed] = PH_read_ripsur('vr_d6VXX_B.txt', 1);

figure; 
plot(x0_closed,y0_closed,'.r')
hold on; 
plot(x1_closed,y1_closed,'.k')
xlim([0 18])
ylim([0 18])
axis square;
xlabel('birth'); ylabel('death')
xticks([0:4:20])
yticks([0:4:20])
legend('0D homology','1D homology')


%% Lattice path representation

closed_lattice = PH_latticepath3(x1_closed,y1_closed);
figure; plot(closed_lattice,'--k', 'LineWidth', 2)

open_lattice = PH_latticepath3(x1_open,y1_open);
hold on; plot(open_lattice,'-r', 'LineWidth', 2)

legend('6VXX-B', '6VYB-B')


%% Transfromation to normalized monotone function \phi.
[closed_phi,open_phi, x, d]= PH_mono2(closed_lattice, open_lattice);

figure; plot(x,closed_phi, '--k', 'LineWidth', 2)
hold on; plot(x,open_phi,'-r', 'LineWidth', 2)
legend('6VXX-B', '6VYB-B')

%------------- 
% Exact topological inference (ETI) providing 
% p-value of testing differences

P = PH_Aasym2([length(closed_lattice), length(open_lattice)] ,d)

%% WARNING PH_latticepath3.m is changed and the computed maximum gap d will be slightly 
%% different than the published results. However, statistical results will be consistently given.

